
from dynamof.operations.add import add
from dynamof.operations.create import create
from dynamof.operations.delete import delete
from dynamof.operations.describe import describe
from dynamof.operations.find import find
from dynamof.operations.query import query
from dynamof.operations.update import update
from dynamof.operations.scan import scan

from dynamof.attribute import attr, cand, cor

from dynamof.db import db
from dynamof.table import table
